pub struct SccRegion {
pub representative: BasicBlock,
pub blocks: Vec<BasicBlock>,
pub exits: Vec<SccRegionExit>,
pub backedges: Vec<(BasicBlock, BasicBlock)>,
}Expand description
A cyclic SCC region specialized for MIR basic blocks.
Fields
representative: BasicBlockStable representative block used as the key for this SCC region.
blocks: Vec<BasicBlock>Blocks that belong to the SCC region.
exits: Vec<SccRegionExit>Edges that leave the SCC region.
backedges: Vec<(BasicBlock, BasicBlock)>Edges inside the SCC region that go back to an earlier block or the representative.